var user_id;
var customer_id;

document.addEventListener('DOMContentLoaded', () => {
    initializeCharts();
    fetchUserIdFromSession();

    // Setup event listeners for static and dynamically added dropdown buttons
    document.addEventListener('click', function(event) {
        const target = event.target;
        // Check if the clicked element or its parent is a dropbtn
        const dropBtn = target.closest('.dropbtn');

        if (dropBtn) {
            // Prevent the click event from closing the dropdown immediately
            event.stopPropagation();

            // Find the closest parent that has either 'company-name' or 'user-info' class
            const parentContainer = dropBtn.closest('.company-name, .user-info');

            // Toggle the dropdown content within this container
            const dropdownContent = parentContainer.querySelector('.dropdown-content');
            if (dropdownContent) {
                dropdownContent.classList.toggle('show');
            }
        } else {
            // Clicked outside, close all dropdowns
            closeAllDropdowns();
        }
    });

    // Close dropdowns when clicking outside
    document.body.addEventListener('click', closeAllDropdowns);

    // Setup event listener for the "Risk Assessment" sidebar link
    const riskAssessmentLink = document.querySelector('.sidebar-link[href="#risk-assessment"]');
    if (riskAssessmentLink) {
        riskAssessmentLink.addEventListener('click', function(event) {
            event.preventDefault(); // Prevent the default navigation
            openRAandRTP(); // Call the function when the link is clicked
        });
    }
});

function closeAllDropdowns() {
    document.querySelectorAll('.dropdown-content.show').forEach(dropdownContent => {
        dropdownContent.classList.remove('show');
    });
}


function initializeCharts() {
  // Context for the bar chart
  const barCtx = document.getElementById('barChart').getContext('2d');
  const barChart = new Chart(barCtx, {
    type: 'bar',
    data: {
      labels: ['Admin', 'User', 'Client'],
      datasets: [{
        data: [5, 6, 7],
        backgroundColor: ['Green', 'lightblue', 'blue']
      }]
    },
    options: {
       plugins: {
            legend: {
                display: false
      },
      title: {
        display: true,
        text: 'User Allocation',
        position: 'top',
        font: {
          size: 16
          }
        }
      }
    }
  });
  // Context for the pie chart
  const pieCtx = document.getElementById('pieChart').getContext('2d');
  const pieChart = new Chart(pieCtx, {
    type: 'pie',
    data: {
      labels: ['Closed Projects', 'Open Projects'],
      datasets: [{
        data: [6, 4],
        backgroundColor: ['Green', 'lightblue']
      }]
    },
    options: {
      plugins: {
        title: {
          display: true,
          text: 'Projects Status',
          position: 'top',
          font: {
            size: 16
          }
        }
      }
    }
  });
}


function fetchUserIdFromSession() {
    // Make a GET request to a server endpoint that returns the session data
    fetch('/get-user-id', {
        method: 'GET',
        credentials: 'include',
    })
    .then(response => response.json())
    .then(data => {
        // Check if 'user_id' is available in the session data
        if (data.user_id !== undefined) {
            user_id = data.user_id;
            console.log('User ID:', user_id);

            // Fetch user data using 'user_id'
            fetchUserData(user_id);
        } else {
            console.error('User is not authenticated or session data is missing.');
        }
    })
    .catch(error => console.error('Error fetching user session data:', error));
}

function fetchUserData(user_Id) {
    const apiUrl = `/api/user-data/${user_Id}`;

    // Make a GET request to the API endpoint
    fetch(apiUrl)
        .then(response => {
            if (!response.ok) {
                throw new Error('Network response was not ok');
            }
            return response.json();
        })
        .then(data => {
            customer_id = data.customer_id;
            // Creating a UserData object with the response data
            const userData = {
                first_name: data.first_name,
                last_name: data.last_name,
                last_login: data.last_login,
                customer_id: data.customer_id,
            };
            updateUserUI(userData);
            console.log(userData);
        })
        .catch(error => {
            // Handle errors that occurred during the fetch request
            console.error('Fetch error:', error);
        });
}

function updateUserUI(userData) {
    // Update the UI with the user data
    document.getElementById('firstName').textContent = userData.first_name;
    document.getElementById('lastName').textContent = userData.last_name;

}
